;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "numeri" "20250907.2357"
  "Roman Numeral Conversion Library."
  '((emacs "29.1"))
  :url "https://github.com/kickingvegas/numeri"
  :commit "625694f596d8f54be8ba8f2a8002287f4cd4f6de"
  :revdesc "625694f596d8"
  :keywords '("tools")
  :authors '(("Charles Choi" . "kickingvegas@gmail.com"))
  :maintainers '(("Charles Choi" . "kickingvegas@gmail.com")))
